cmd

package
v0.0.0-...-4933043 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2017 License: Apache-2.0 Imports: 14 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

var RootCmd = &cobra.Command{
	Use:   "mcc",
	Short: "A CLI to interact with the Project Voyager Houston API",
}

RootCmd represents the base command when called without any subcommands

Functions

func CheckMccTarget

func CheckMccTarget() (url.URL, error)

CheckMccTarget is a helper function that reads mcc target

func Execute

func Execute()

Execute adds all child commands to the root command sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type InfoResponse

type InfoResponse struct {
	Name string
}

InfoResponse is the response from the info call

type NodesResponse

type NodesResponse struct {
	ID     string `json:"ID"`
	Type   string `json:"Type"`
	Status string `json:"Status"`
	IP     string `json:"IP"`
}

NodesResponse is ...

Jump to