Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var RootCmd = &cobra.Command{
Use: "mcc",
Short: "A CLI to interact with the Project Voyager Houston API",
}
RootCmd represents the base command when called without any subcommands
Functions ¶
func CheckMccTarget ¶
CheckMccTarget is a helper function that reads mcc target
Types ¶
type InfoResponse ¶
type InfoResponse struct {
Name string
}
InfoResponse is the response from the info call
Click to show internal directories.
Click to hide internal directories.